Topic Modeling — Orange3 Text Mining documentation

# Topic Modeling

class orangecontrib.text.topics.LdaWrapper(**kwargs)
  __init__(**kwargs)
  fit(corpus, **kwargs)

    Train the model with the corpus.

    Parameters

      corpus (Corpus) – A corpus to learn topics from.

  transform(corpus)

    Create a table with topics representation.

class orangecontrib.text.topics.LsiWrapper(**kwargs)
  __init__(**kwargs)
  fit(corpus, **kwargs)

    Train the model with the corpus.

    Parameters

      corpus (Corpus) – A corpus to learn topics from.

  transform(corpus)

    Create a table with topics representation.

class orangecontrib.text.topics.HdpWrapper(**kwargs)
  __init__(**kwargs)
  fit(corpus, **kwargs)

    Train the model with the corpus.

    Parameters

      corpus (Corpus) – A corpus to learn topics from.

  transform(corpus)

    Create a table with topics representation.